import { utils } from 'ethers';
import { serializeError } from 'eth-rpc-errors';
export function format(first, middle, last) {
  return ((first || '') + (middle ? ` ${middle}` : '') + (last ? ` ${last}` : ''));
}
export function formatEthers(value) {
  return utils.formatEther(value);
}
export function getBlockExplorer(testnet) {
  return testnet ? 'https://goerli.etherscan.io' : 'https://etherscan.io';
}
export function handleError(e) {
  const fallbackError = {
    code: -6666,
    message: 'Something went horribly wrong',
  };
  console.error(e);
  if ((e === null || e === void 0 ? void 0 : e.code) && e.code === 4001) {
    return 'You rejected the transaction in your wallet';
  }
  if (e === null || e === void 0 ? void 0 : e.message.includes('cannot estimate gas')) {
    return 'Cannot estimate gas';
  }
  if (e === null || e === void 0 ? void 0 : e.message.includes('insufficient funds')) {
    return 'Your wallet does not have enough balance.';
  }
  if (e === null || e === void 0 ? void 0 : e.message('Exceeded max per wallet')) {
    return 'Exceeded max per wallet';
  }
  const error = serializeError(e, { fallbackError, shouldIncludeStack: true });
  throw Error(error.message);
}
